# sageodata_db

SA Geodata database querying tool/wrapper/library for Python

## Install

The source code is on [Bitbucket](https://bitbucket.org/dewsurfacewater/sageodata_db), while Python packages (source and binary) are published on
the [Python Package Index](https://pypi.org/project/sageodata-db/) and 
on a dedicated channel on [Anaconda Cloud](https://anaconda.org/dew-waterscience/repo).

### From PyPI (most recent release)

Run this in Command Prompt to install from PyPI:

```
pip install sageodata_db
```

To upgrade to the latest version:

```
pip install -U sageodata_db
```

### From Anaconda 

You can also install using conda/mamba if you prefer:

```
mamba install -c dew-waterscience saegodata_db
```

To upgrade:

```
mamba upgrade -c dew-waterscience sageodata_db
```

The version may not be as up-to-date as the PyPI version.

### From Bitbucket

This is how you can install the latest version of the source code directly from Bitbucket (the version control repository):

```
python -m pip install git+https://kinveraritysagov@bitbucket.org/dewsurfacewater/sageodata_db.git
```

You will need to replace ``kinveraritysagov`` with your Bitbucket username, and you will also need access to the source repository on the Bitbucket dewsurfacewater workspace.

## Usage

Check out complete documentation at:

[http://bunyip:8191/python-docs/sageodata_db/latest_source/index.html](http://bunyip:8191/python-docs/sageodata_db/latest_source/index.html)

## License

All rights reserved DEW 2023
